<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr">
<context>
    <name>QObject</name>
    <message>
        <location filename="../qsynthSetup.cpp" line="37"/>
        <source>(default)</source>
        <translation>(подразумевано)</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="224"/>
        <source>Usage: %1 [options] [soundfonts] [midifiles]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="227"/>
        <source>Options</source>
        <translation type="unfinished">Параметри</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="229"/>
        <location filename="../qsynthOptions.cpp" line="285"/>
        <source>Don&apos;t create a midi driver to read MIDI input events [default = yes]</source>
        <translation type="unfinished">Не стварај миди посредника за читање улазних миди-догађаја [подразумевано = yes]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="231"/>
        <location filename="../qsynthOptions.cpp" line="287"/>
        <source>The name of the midi driver to use [oss,alsa,alsa_seq,...]</source>
        <translation type="unfinished">Назив миди посредника који ће се користити [oss,alsa,alsa_seq,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="233"/>
        <location filename="../qsynthOptions.cpp" line="289"/>
        <source>The number of midi channels [default = 16]</source>
        <translation type="unfinished">Број миди-канала [подразумевано = 16]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="235"/>
        <location filename="../qsynthOptions.cpp" line="291"/>
        <source>The audio driver [alsa,jack,oss,dsound,...]</source>
        <translation type="unfinished">Звучни посредник [alsa,jack,oss,dsound,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="237"/>
        <location filename="../qsynthOptions.cpp" line="293"/>
        <source>Attempt to connect the jack outputs to the physical ports</source>
        <translation type="unfinished">Покушавај да повежеш излазе Џек посредника на физичке портове</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="239"/>
        <location filename="../qsynthOptions.cpp" line="295"/>
        <source>The number of stereo audio channels [default = 1]</source>
        <translation type="unfinished">Број звучних стерео канала [подразумевано = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="241"/>
        <location filename="../qsynthOptions.cpp" line="297"/>
        <source>The number of audio groups [default = 1]</source>
        <translation type="unfinished">Број звучних група [подразумевано = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="243"/>
        <location filename="../qsynthOptions.cpp" line="299"/>
        <source>Size of each audio buffer</source>
        <translation type="unfinished">Величина сваког звучног бафера</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="245"/>
        <location filename="../qsynthOptions.cpp" line="301"/>
        <source>Number of audio buffers</source>
        <translation type="unfinished">Број звучних бафера</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="247"/>
        <location filename="../qsynthOptions.cpp" line="303"/>
        <source>Set the sample rate</source>
        <translation type="unfinished">Постави учестаност узорковања</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="249"/>
        <location filename="../qsynthOptions.cpp" line="305"/>
        <source>Turn the reverb on or off [1|0|yes|no|on|off, default = on]</source>
        <translation type="unfinished">Укљ./Искљ. јека еф. [1|0|yes|no|on|off, подразумевано = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="251"/>
        <location filename="../qsynthOptions.cpp" line="307"/>
        <source>Turn the chorus on or off [1|0|yes|no|on|off, default = on]</source>
        <translation type="unfinished">Укљ./Искљ. хорус еф. [1|0|yes|no|on|off, подразумевано = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="253"/>
        <location filename="../qsynthOptions.cpp" line="309"/>
        <source>Set the master gain [0 &lt; gain &lt; 2, default = 1]</source>
        <translation type="unfinished">Постави Мастер-појачање [0 &lt; gain &lt; 2, подразумевано = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="255"/>
        <location filename="../qsynthOptions.cpp" line="311"/>
        <source>Define a setting name=value</source>
        <translation type="unfinished">Одреди назив поставке=вредност</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="257"/>
        <location filename="../qsynthOptions.cpp" line="313"/>
        <source>Create and start server [default = no]</source>
        <translation type="unfinished">Створи и покрени сервер [подразумевано = no]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="259"/>
        <location filename="../qsynthOptions.cpp" line="315"/>
        <source>Don&apos;t read commands from the shell [ignored]</source>
        <translation type="unfinished">Не читај команде из наредбене линије [занемарено]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="261"/>
        <location filename="../qsynthOptions.cpp" line="317"/>
        <source>Dump midi router events</source>
        <translation type="unfinished">Избаци догађаје миди-рутера</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="263"/>
        <location filename="../qsynthOptions.cpp" line="319"/>
        <source>Print out verbose messages about midi events</source>
        <translation type="unfinished">Штампај опширније поруке о миди-догађајима</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="265"/>
        <source>Show help about command line options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="267"/>
        <source>Show version information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="323"/>
        <source>SoundFont Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="324"/>
        <source>[soundfonts]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="326"/>
        <source>MIDI Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="327"/>
        <source>[midifiles]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="337"/>
        <location filename="../qsynthOptions.cpp" line="513"/>
        <source>Option -m requires an argument (midi-driver).</source>
        <translation type="unfinished">Опција „-m“ захтева аргумент (миди посредник).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="347"/>
        <location filename="../qsynthOptions.cpp" line="522"/>
        <source>Option -K requires an argument (midi-channels).</source>
        <translation type="unfinished">Опција „-K“ захтева аргумент (миди-канали).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="356"/>
        <location filename="../qsynthOptions.cpp" line="531"/>
        <source>Option -a requires an argument (audio-driver).</source>
        <translation type="unfinished">Опција „-a“ захтева аргумент (звучни посредник).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="370"/>
        <location filename="../qsynthOptions.cpp" line="543"/>
        <source>Option -L requires an argument (audio-channels).</source>
        <translation type="unfinished">Опција „-L“ захтева аргумент (звучни канали).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="380"/>
        <location filename="../qsynthOptions.cpp" line="552"/>
        <source>Option -G requires an argument (audio-groups).</source>
        <translation type="unfinished">Опција „-G“ захтева аргумент (звучне групе).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="390"/>
        <location filename="../qsynthOptions.cpp" line="561"/>
        <source>Option -z requires an argument (audio-bufsize).</source>
        <translation type="unfinished">Опција „-z“ захтева аргумент (вел. зв. бафера).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="400"/>
        <location filename="../qsynthOptions.cpp" line="570"/>
        <source>Option -c requires an argument (audio-bufcount).</source>
        <translation type="unfinished">Опција „-c“ захтева аргумент (број зв. бафера).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="410"/>
        <location filename="../qsynthOptions.cpp" line="579"/>
        <source>Option -r requires an argument (sample-rate).</source>
        <translation type="unfinished">Опција „-r“ захтева аргумент (учестаност узорковања).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="438"/>
        <location filename="../qsynthOptions.cpp" line="606"/>
        <source>Option -g requires an argument (gain).</source>
        <translation type="unfinished">Опција „-g“ захтева аргумент (појачање).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="447"/>
        <location filename="../qsynthOptions.cpp" line="615"/>
        <source>Option -o requires an argument.</source>
        <translation type="unfinished">Опција „-o“ захтева аргумент.</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="482"/>
        <location filename="../qsynthOptions.cpp" line="664"/>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation type="unfinished">Непозната опција „%1“.</translation>
    </message>
</context>
<context>
    <name>qsynthAboutForm</name>
    <message>
        <location filename="../qsynthAboutForm.ui" line="33"/>
        <source>About</source>
        <translation>О програму</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Затвори</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="74"/>
        <source>About Qt</source>
        <translation>О КуТ</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="62"/>
        <source>Version</source>
        <translation>Издање</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="43"/>
        <source>Debugging option enabled.</source>
        <translation>Омогућено праћење грешака.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="46"/>
        <source>System tray disabled.</source>
        <translation>Онемогућена икона у обавештајној зони.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="49"/>
        <source>Server option disabled.</source>
        <translation>Онемогућена серверска опција.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="52"/>
        <source>System reset option disabled.</source>
        <translation>Онемогућена опција поновног покретања система.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="55"/>
        <source>Bank offset option disabled.</source>
        <translation>Онемогућена опција офсет банке.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="70"/>
        <source>Using: Qt %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="76"/>
        <source>FluidSynth %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="80"/>
        <source>Website</source>
        <translation>Интернет страница</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="85"/>
        <source>This program is free software; you can redistribute it and/or modify it</source>
        <translation>Овај програм је слободан софтвер; можете га прослеђивати и/или мењати</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="86"/>
        <source>under the terms of the GNU General Public License version 2 or later.</source>
        <translation>под условима ГНУ Опште Јавне Лиценце верзије 2 или (по вашем избору) било које касније верзије.</translation>
    </message>
</context>
<context>
    <name>qsynthChannelsForm</name>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="59"/>
        <source>Preset &amp;Name:</source>
        <translation>&amp;Назив поставке:</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="80"/>
        <source>Settings preset name</source>
        <translation>Подешавања назива поставке</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="87"/>
        <source>(default)</source>
        <translation>(подразумевано)</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="95"/>
        <source>Save settings as current preset name</source>
        <translation>Сачувај подешавања као текући назив поставке</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="98"/>
        <source>&amp;Save</source>
        <translation>&amp;Сачувај</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="111"/>
        <source>Delete current settings preset</source>
        <translation>Уклони текуће подешавање поставке</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="114"/>
        <source>&amp;Delete</source>
        <translation>&amp;Уклони</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="146"/>
        <source>Channels view</source>
        <translation>Преглед канала</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="171"/>
        <source>In</source>
        <translation>Ул.</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="176"/>
        <source>Chan</source>
        <translation>Канал</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="181"/>
        <source>Bank</source>
        <translation>Банка</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="186"/>
        <source>Prog</source>
        <translation>Програм</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="191"/>
        <source>Name</source>
        <translation>Назив</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="196"/>
        <source>SFID</source>
        <translation>З-ИБ</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="201"/>
        <source>Soundfont</source>
        <translation>Звукотека</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="36"/>
        <source>Channels</source>
        <translation>Канали</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="355"/>
        <source>Edit</source>
        <translation>Уреди</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="360"/>
        <source>Unset</source>
        <translation>Ослободи</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="364"/>
        <source>Refresh</source>
        <translation>Освежи</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="492"/>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="493"/>
        <source>Delete preset:</source>
        <translation>Уклањање поставке:</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="495"/>
        <source>Are you sure?</source>
        <translation>Да ли сте сигурни?</translation>
    </message>
</context>
<context>
    <name>qsynthMainForm</name>
    <message>
        <location filename="../qsynthMainForm.ui" line="46"/>
        <source>Master</source>
        <translation>Мастер</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="64"/>
        <source>&amp;Gain</source>
        <translation>По&amp;јачање</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="86"/>
        <location filename="../qsynthMainForm.ui" line="111"/>
        <source>Master Gain</source>
        <translation>Главни појачавач</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="127"/>
        <source>Complete engine restart</source>
        <translation>Наново покрени све</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="130"/>
        <location filename="../qsynthMainForm.cpp" line="1371"/>
        <location filename="../qsynthMainForm.cpp" line="1466"/>
        <source>Re&amp;start</source>
        <translation>Ре&amp;старт</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="146"/>
        <source>Reverb</source>
        <translation>Јека</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="170"/>
        <source>Reverb effect activation</source>
        <translation>Покретање ефекта јеке</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="173"/>
        <source>Ac&amp;tive</source>
        <translation>О&amp;могући</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="186"/>
        <location filename="../qsynthMainForm.ui" line="205"/>
        <source>Reverb Level</source>
        <translation>Количина ефекта јеке</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="230"/>
        <source>&amp;Level</source>
        <translation>Ко&amp;личина</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="252"/>
        <location filename="../qsynthMainForm.ui" line="293"/>
        <source>Reverb Width</source>
        <translation>Ширина ефекта јеке</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="271"/>
        <source>&amp;Width</source>
        <translation>&amp;Ширина</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="318"/>
        <location filename="../qsynthMainForm.ui" line="359"/>
        <source>Reverb Damp Factor</source>
        <translation>Фактор пригушивања ефекта јеке</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="337"/>
        <source>D&amp;amp</source>
        <translation>При&amp;гушено</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="384"/>
        <location filename="../qsynthMainForm.ui" line="425"/>
        <source>Reverb Room Size</source>
        <translation>Величина собе за ефекат јеке</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="403"/>
        <source>R&amp;oom</source>
        <translation>С&amp;оба</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="453"/>
        <source>Chorus</source>
        <translation>Хорус</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="477"/>
        <source>Chorus Modulation Type</source>
        <translation>Врста модулације за хорус ефекат</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="481"/>
        <source>Sine</source>
        <translation>синусна</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="486"/>
        <source>Triangle</source>
        <translation>троугласта</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="506"/>
        <source>T&amp;ype:</source>
        <translation>Врс&amp;та:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="534"/>
        <source>Chorus effect activation</source>
        <translation>Покретање хорус ефекта</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="537"/>
        <source>Act&amp;ive</source>
        <translation>Омогућ&amp;и</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="550"/>
        <location filename="../qsynthMainForm.ui" line="597"/>
        <source>Number of Chorus Stages</source>
        <translation>Број етапа хорус ефекта</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="575"/>
        <source>&amp;N</source>
        <translation>&amp;Број</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="616"/>
        <location filename="../qsynthMainForm.ui" line="663"/>
        <source>Chorus Level</source>
        <translation>Количина хорус ефекта</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="641"/>
        <source>Le&amp;vel</source>
        <translation>Коли&amp;чина</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="682"/>
        <location filename="../qsynthMainForm.ui" line="735"/>
        <source>Chorus Speed (Hz)</source>
        <translation>Брзина хоруса (Hz)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="710"/>
        <source>Chorus Speed Hz</source>
        <translation>Брзина хоруса у херцима</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="713"/>
        <source>Spee&amp;d</source>
        <translation>Брзин&amp;а</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="757"/>
        <location filename="../qsynthMainForm.ui" line="804"/>
        <source>Chorus Depth (ms)</source>
        <translation>Дубина хоруса у милисекундама</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="782"/>
        <source>Dept&amp;h</source>
        <translation>&amp;Дубина</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="829"/>
        <source>Output peak level</source>
        <translation>Ниво вршних  вредности на излазу</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="847"/>
        <source>Quit this application</source>
        <translation>Напуштање програма</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="850"/>
        <location filename="../qsynthMainForm.cpp" line="1418"/>
        <source>&amp;Quit</source>
        <translation>И&amp;злаз</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="863"/>
        <source>Show general options dialog</source>
        <translation>Прикажи прозорче са општим опцијама</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="866"/>
        <location filename="../qsynthMainForm.cpp" line="1412"/>
        <source>&amp;Options...</source>
        <translation>&amp;Опције…</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="879"/>
        <source>Show/hide the messages log window</source>
        <translation>Приказује/Скрива прозорче за преглед дневника са порукама</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="882"/>
        <location filename="../qsynthMainForm.cpp" line="1408"/>
        <source>&amp;Messages</source>
        <translation>Порук&amp;е</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="898"/>
        <source>Show information about this application</source>
        <translation>Прикажи податке о овом програму</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="901"/>
        <source>A&amp;bout...</source>
        <translation>О про&amp;граму…</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="932"/>
        <source>System reset</source>
        <translation>Ресет система</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="935"/>
        <location filename="../qsynthMainForm.cpp" line="1376"/>
        <source>&amp;Panic</source>
        <translation>&amp;Узбуна</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="945"/>
        <source>Program reset (all channels)</source>
        <translation>Ресет програма (на свим каналима)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="948"/>
        <location filename="../qsynthMainForm.cpp" line="1373"/>
        <source>&amp;Reset</source>
        <translation>&amp;Ресет</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="958"/>
        <source>Show instance settings and configuration dialog</source>
        <translation>Приказује прозорче поставки и подешавања</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="961"/>
        <location filename="../qsynthMainForm.cpp" line="1385"/>
        <location filename="../qsynthMainForm.cpp" line="1858"/>
        <source>Set&amp;up...</source>
        <translation>&amp;Поставке…</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="974"/>
        <source>Show/hide the channels view window</source>
        <translation>Приказује/Скрива прозорче за преглед канала</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="977"/>
        <location filename="../qsynthMainForm.cpp" line="1380"/>
        <source>&amp;Channels</source>
        <translation>&amp;Канали</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1016"/>
        <source>Add a new engine</source>
        <translation>Додај нови покретач</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1029"/>
        <source>Engine selector (right-click for menu)</source>
        <translation>Избор покретача (десни клик за мени)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1067"/>
        <source>Delete current engine</source>
        <translation>Уклони текући покретач</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="842"/>
        <source>Information</source>
        <translation>Подаци</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="844"/>
        <source>The program will keep running in the system tray.

To terminate the program, please choose &quot;Quit&quot;
in the context menu of the system tray icon.</source>
        <translation>Програм ће остати покренут у обавештајној зони.

За затварање програма, одаберите „Излаз“
из контекстног менија на икони у обавештајној зони.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="860"/>
        <source>Don&apos;t show this message again</source>
        <translation>Не приказуј ово поново</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="885"/>
        <location filename="../qsynthMainForm.cpp" line="1595"/>
        <location filename="../qsynthMainForm.cpp" line="2344"/>
        <location filename="../qsynthMainForm.cpp" line="2374"/>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="887"/>
        <source>is about to terminate.</source>
        <translation>ће завршити са радом.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="888"/>
        <location filename="../qsynthMainForm.cpp" line="1598"/>
        <source>Are you sure?</source>
        <translation>Да ли сте сигурни?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="898"/>
        <source>Don&apos;t ask this again</source>
        <translation>Не питај ме ово поново</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="996"/>
        <source>Loading soundfont: &quot;%1&quot;</source>
        <translation>Учитавање звукотеке: „%1“</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1007"/>
        <location filename="../qsynthMainForm.cpp" line="2034"/>
        <source>Failed to load the soundfont: &quot;%1&quot;.</source>
        <translation>Није успело учитавање звукотеке: „%1“.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1034"/>
        <source>Playing MIDI file: &quot;%1&quot;</source>
        <translation>Свирам миди датотеку: „%1“</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1041"/>
        <source>Failed to play MIDI file: &quot;%1&quot;.</source>
        <translation>Нисам успео да одсвирам миди датотеку: „%1“.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1246"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1354"/>
        <source>&amp;Hide</source>
        <translation>&amp;Сакриј</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1350"/>
        <source>Mi&amp;nimize</source>
        <translation>У&amp;мањи</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1355"/>
        <source>S&amp;how</source>
        <translation>При&amp;кажи</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1351"/>
        <source>Rest&amp;ore</source>
        <translation>Вра&amp;ти</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1363"/>
        <location filename="../qsynthMainForm.cpp" line="1852"/>
        <source>&amp;New engine...</source>
        <translation>&amp;Нови покретач…</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1365"/>
        <location filename="../qsynthMainForm.cpp" line="1854"/>
        <source>&amp;Delete</source>
        <translation>&amp;Уклони</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1371"/>
        <location filename="../qsynthMainForm.cpp" line="1468"/>
        <source>&amp;Start</source>
        <translation>&amp;Старт</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1391"/>
        <source>Engines</source>
        <translation>Покретачи</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1596"/>
        <source>Delete fluidsynth engine:</source>
        <translation>Уклони флуид-синт покретач:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1993"/>
        <source>Creating synthesizer engine</source>
        <translation>Створи покретач синтисајзера</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1997"/>
        <source>Failed to create the synthesizer.

Cannot continue without it.</source>
        <translation>Нисам успео да створим синтисајзер.

Не могу да радим без њега.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2028"/>
        <source>Loading soundfont: &quot;%1&quot; (bank offset %2)</source>
        <translation>Учитавање звукотеке: „%1“ (офсет банке %2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2041"/>
        <source>Failed to set bank offset (%1) for soundfont: &quot;%2&quot;.</source>
        <translation>Нисам успео да поставим офсет банке (%1) за звукотеку: „%2“.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2051"/>
        <source>Creating audio driver (%1)</source>
        <translation>Стварање звучног посредника (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2065"/>
        <source>Failed to create the audio driver (%1).

Cannot continue without it.</source>
        <translation>Није успело стварање зв. посредника (%1).

Не могу да радим без њега.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2078"/>
        <source>Creating MIDI router (%1)</source>
        <translation>Стварање миди-рутера (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2087"/>
        <source>Failed to create the MIDI input router (%1).

No MIDI input will be available.</source>
        <translation>Нисам успео да створим улазни миди рутер (%1).

Миди-улази неће бити доступни.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2095"/>
        <source>Creating MIDI driver (%1)</source>
        <translation>Стварање миди посредника (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2104"/>
        <source>Failed to create the MIDI driver (%1).

No MIDI input will be available.</source>
        <translation>Нисам успео да створим миди посредника (%1).

Миди-улази неће бити доступни.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1023"/>
        <source>Creating MIDI player</source>
        <translation>Стварање миди-свирача</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1027"/>
        <source>Failed to create the MIDI player.

Continuing without a player.</source>
        <translation>Нисам успео да створим миди-свирача.

Настављам без њега.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2113"/>
        <source>Creating server</source>
        <translation>Стварање сервера</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2147"/>
        <source>Failed to create the server.

Continuing without it.</source>
        <translation>Нисам успео да створим сервер.

Не могу да радим без њега.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2151"/>
        <source>Server mode disabled.

Continuing without it.</source>
        <translation>Онемогућено је серверски режим.

Настављам без њега.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2185"/>
        <source>Synthesizer engine started.</source>
        <translation>Покретач синтисајзера је у употреби.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2228"/>
        <source>Destroying server</source>
        <translation>Уништавање сервера</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2236"/>
        <source>Stopping MIDI player</source>
        <translation>Заустављање миди-свирача</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2238"/>
        <source>Waiting for MIDI player to terminate</source>
        <translation>Чекам да се заустави миди-свирач</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1017"/>
        <location filename="../qsynthMainForm.cpp" line="2240"/>
        <source>Destroying MIDI player</source>
        <translation>Уништавање миди-свирача</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2248"/>
        <source>Destroying MIDI driver</source>
        <translation>Уништавање миди-посредника</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2252"/>
        <source>Destroying MIDI router</source>
        <translation>Уништавање миди-рутера</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2259"/>
        <source>Destroying audio driver</source>
        <translation>Уништавање звучног посредника</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2282"/>
        <source>Unloading soundfont: &quot;%1&quot; (SFID=%2)</source>
        <translation>Избацивање звукотеке: „%1“ (З-ИБ=%2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2286"/>
        <source>Failed to unload the soundfont: &quot;%1&quot;.</source>
        <translation>Није успело избацивање звукотеке: „%1“.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2293"/>
        <source>Destroying synthesizer engine</source>
        <translation>Уништавање покретача синтисајзера</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2297"/>
        <source>Synthesizer engine terminated.</source>
        <translation>Покретач синтисајзера је заустављен.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2345"/>
        <source>New settings will be effective after
restarting all fluidsynth engines.</source>
        <translation>Нова подешавања ће се применити само по 
поновном покретању флуид-синт покретача.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2347"/>
        <location filename="../qsynthMainForm.cpp" line="2378"/>
        <source>Please note that this operation may cause
temporary MIDI and Audio disruption.</source>
        <translation>Ова радња може довести до привремених 
миди и звучних поремећаја у раду.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2349"/>
        <source>Do you want to restart all engines now?</source>
        <translation>Желите ли да поново покренете све покретаче?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2375"/>
        <source>New settings will be effective after
restarting the fluidsynth engine:</source>
        <translation>Нова подешавања ће се применити само по 
поновном покретању флуид-синт покретача:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2380"/>
        <source>Do you want to restart the engine now?</source>
        <translation>Желите ли да поново покренете овај покретач?</translation>
    </message>
</context>
<context>
    <name>qsynthMessagesForm</name>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="33"/>
        <source>Messages</source>
        <translation>Поруке</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="48"/>
        <source>Messages output log</source>
        <translation>Дневник порука на излазу</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="133"/>
        <source>Logging stopped --- %1 ---</source>
        <translation>Праћење порука заустављено --- %1 ---</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="143"/>
        <source>Logging started --- %1 ---</source>
        <translation>Праћење порука започето --- %1 ---</translation>
    </message>
</context>
<context>
    <name>qsynthOptionsForm</name>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="461"/>
        <source>Display</source>
        <translation>Приказ</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="62"/>
        <source>Messages</source>
        <translation>Поруке</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="50"/>
        <source>General</source>
        <translation>Опште</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="89"/>
        <source>Sample messages text font display</source>
        <translation>Пример приказа слова текстуалних порука</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="117"/>
        <source>Select font for the messages text display</source>
        <translation>Одабир словолика за приказ текстуалних порука</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="120"/>
        <source>&amp;Font...</source>
        <translation>&amp;Словолик…</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="152"/>
        <source>Whether to keep a maximum number of lines in the messages window</source>
        <translation>Омогућава ограничавање броја линија у прозорчету са порукама које треба задржати</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="155"/>
        <source>&amp;Messages limit:</source>
        <translation>Ограничавање у порук&amp;ма:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="168"/>
        <source>The maximum number of message lines to keep in view</source>
        <translation>Највећи број линија у прозорчету са порукама које треба задржати</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="178"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="183"/>
        <source>250</source>
        <translation>250</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="188"/>
        <source>500</source>
        <translation>500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="193"/>
        <source>1000</source>
        <translation>1000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="198"/>
        <source>2500</source>
        <translation>2500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="203"/>
        <source>5000</source>
        <translation>5000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="220"/>
        <source>Logging</source>
        <translation>Дневник рада</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="241"/>
        <source>Messages log file</source>
        <translation>Датотека дневника порука</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="272"/>
        <source>Browse for the messages log file location</source>
        <translation>Разгледај за путањом до датотеке дневника порука</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="275"/>
        <location filename="../qsynthOptionsForm.ui" line="694"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="288"/>
        <source>Whether to activate a messages logging to file.</source>
        <translation>Омогућава вођење дневника са порукама у датотеци.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="291"/>
        <source>Messages &amp;log file:</source>
        <translation>Датотека &amp;дневника порука:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="473"/>
        <source>Knobs</source>
        <translation>Дугмад</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="488"/>
        <source>Kno&amp;b graphic style:</source>
        <translation>Изглед ду&amp;гмади:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="504"/>
        <source>Graphic style for knobs</source>
        <translation>Подешавање графичког приказа (изгледа) дугмади</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="508"/>
        <source>Classic</source>
        <translation>подразумевано</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="513"/>
        <source>Vokimon</source>
        <translation>воукимон</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="518"/>
        <source>Peppino</source>
        <translation>пепино</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="523"/>
        <source>Skulpture</source>
        <translation>скулптура</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="528"/>
        <location filename="../qsynthOptionsForm.ui" line="584"/>
        <source>Legacy</source>
        <translation>старински</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="558"/>
        <source>Mouse motion be&amp;havior:</source>
        <translation>Управља&amp;ње мишом:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="577"/>
        <source>Mouse motion behavior for knobs</source>
        <translation>Подешавање управљања дугмадима помоћу миша</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="589"/>
        <source>Radial</source>
        <translation>кружно</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="594"/>
        <source>Linear</source>
        <translation>линијски</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="611"/>
        <source>Custom</source>
        <translation>Прилагођено</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="626"/>
        <source>&amp;Color palette theme:</source>
        <translation>Тема са палетом &amp;боја:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="645"/>
        <source>Custom color palette theme</source>
        <translation>Прилагођена тема са палетом боја</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="657"/>
        <source>Wonton Soup</source>
        <translatorcomment>DO NOT TRANSLATE</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="662"/>
        <source>KXStudio</source>
        <translatorcomment>DO NOT TRANSLATE</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="691"/>
        <source>Manage custom color palette themes</source>
        <translation>Управљање прилагођеном темом са палетом боја</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="720"/>
        <source>&amp;Widget style theme:</source>
        <translation>Тема за &amp;додатке:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="736"/>
        <source>Custom widget style theme</source>
        <translation>Прилагођена тема за додатке</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="307"/>
        <source>Other</source>
        <translation>Остало</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="322"/>
        <source>Whether to ask for confirmation on application exit</source>
        <translation>Да ли да затражим потврду по напуштању програма</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="325"/>
        <source>&amp;Confirm application close</source>
        <translation>Потврда &amp;за напуштање програма</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="415"/>
        <source>Whether to show system tray message on main window close</source>
        <translation>Да ли да прикажем поруку у об. зони по затварању гл. прозора</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="418"/>
        <source>Sho&amp;w system tray message on close</source>
        <translation>Прикажи поруку у обавештајној зони по оконча&amp;њу</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="760"/>
        <source>Defaults</source>
        <translation>Подразумевано</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="338"/>
        <source>Whether to keep all child windows on top of the main window</source>
        <translation>Да ли да издигнем потчињене прозоре у први план</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="34"/>
        <source>Options</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="341"/>
        <source>&amp;Keep child windows always on top</source>
        <translation>Потчињени прозори су у првом п&amp;лану</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="354"/>
        <source>Whether to capture standard output (stdout/stderr) into messages window</source>
        <translation>Да ли да пратим стандардни излаз („stdout/stderr“) кроз прозорче са порукама</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="357"/>
        <source>Capture standard &amp;output</source>
        <translation>Прати стандардни &amp;излаз</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="370"/>
        <source>Whether to monitor and show engine output peak level meters</source>
        <translation>Да ли да пратим и приказујем ниво излазних вршних вредности сигнала</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="373"/>
        <source>Output &amp;peak level meters</source>
        <translation>&amp;Прати ниво вршних вредности покретача</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="399"/>
        <source>Whether to enable the system tray icon</source>
        <translation>Да ли да омогућим употребу иконе у обавештајној зони</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="402"/>
        <source>&amp;Enable system tray icon</source>
        <translation>Омогући икону у обав&amp;ештајној зони</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="431"/>
        <source>Whether to start minimized to system tray</source>
        <translation>Да ли да сакријем програм при покретању у обавештајну зону</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="434"/>
        <source>Start minimi&amp;zed to system tray</source>
        <translation>По покретању смести у &amp;обавештајну зону</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="775"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="819"/>
        <source>&amp;Base font size:</source>
        <translation>Величина &amp;слова:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="838"/>
        <source>Base application font size (pt.)</source>
        <translation>Основна величина слова у програму (у тачкама-пт.)</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="652"/>
        <location filename="../qsynthOptionsForm.ui" line="743"/>
        <location filename="../qsynthOptionsForm.ui" line="792"/>
        <location filename="../qsynthOptionsForm.ui" line="845"/>
        <location filename="../qsynthOptionsForm.cpp" line="44"/>
        <source>(default)</source>
        <translation>(подразумевано)</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="850"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="855"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="860"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="865"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="870"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="875"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="880"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="315"/>
        <source>Information</source>
        <translation>Подаци</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="316"/>
        <source>Some settings may be only effective
next time you start this application.</source>
        <translation>Нека од подешавања ће се применити
само по поновном покретању програма.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="342"/>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="343"/>
        <source>Some options have been changed.</source>
        <translation>Измењена су нека подешавања.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="344"/>
        <source>Do you want to apply the changes?</source>
        <translation>Желите ли да примените ове измене?</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="501"/>
        <source>Messages Log</source>
        <translation>Дневник порука</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="503"/>
        <source>Log files</source>
        <translation>Датотеке дневника</translation>
    </message>
</context>
<context>
    <name>qsynthPaletteForm</name>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="40"/>
        <source>Color Themes</source>
        <translation>Тема боја</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="46"/>
        <source>Name</source>
        <translation>Назив</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="64"/>
        <source>Current color palette name</source>
        <translation>Назив текуће палете боја</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="77"/>
        <source>Save current color palette name</source>
        <translation>Сачувај назив текуће палете боја</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="80"/>
        <source>Save</source>
        <translation>Сачувај</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="90"/>
        <source>Delete current color palette name</source>
        <translation>Уклони назив текуће палете боја</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="93"/>
        <source>Delete</source>
        <translation>Уклони</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="106"/>
        <source>Palette</source>
        <translation>Палета</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="118"/>
        <source>Current color palette</source>
        <translation>Текућа палета боја</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="128"/>
        <source>Generate:</source>
        <translation>Стварај:</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="144"/>
        <source>Base color to generate palette</source>
        <translation>Из основне боје створи палету</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="151"/>
        <source>Reset all current palette colors</source>
        <translation>Поништи све текуће палете боја</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="154"/>
        <source> Reset</source>
        <translation> Поништи</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="177"/>
        <source>Import a custom color theme (palette) from file</source>
        <translation>Увези прилагођену тему боја (палету) из датотеке</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="180"/>
        <source>Import...</source>
        <translation>Увези…</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="190"/>
        <source>Export a custom color theme (palette) to file</source>
        <translation>Извези прилагођену тему боја (палету) у датотеку</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="193"/>
        <source>Export...</source>
        <translation>Извези…</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="216"/>
        <source>Show Details</source>
        <translation>Прикажи детаље</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="323"/>
        <source>Import File - %1</source>
        <translation>Увези датотеку — %1</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="326"/>
        <location filename="../qsynthPaletteForm.cpp" line="400"/>
        <source>Palette files (*.%1)</source>
        <translation>Датотеке палета (*.%1)</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="327"/>
        <location filename="../qsynthPaletteForm.cpp" line="401"/>
        <source>All files (*.*)</source>
        <translation>Све датотеке (*.*)</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="387"/>
        <location filename="../qsynthPaletteForm.cpp" line="820"/>
        <location filename="../qsynthPaletteForm.cpp" line="828"/>
        <source>Warning - %1</source>
        <translation>Упозорење — %1</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="388"/>
        <source>Could not import from file:

%1

Sorry.</source>
        <translation>Не могу да увезем из датотеке:

%1

Праштајте.</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="397"/>
        <source>Export File - %1</source>
        <translation>Извези датотеку — %1</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="821"/>
        <source>Some settings have been changed.

Do you want to discard the changes?</source>
        <translation>Измењена су нека подешавања.

Желите ли да одбаците ове измене?</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="829"/>
        <source>Some settings have been changed:

&quot;%1&quot;.

Do you want to save the changes?</source>
        <translation>Измењена су нека подешавања:

&quot;%1&quot;.

Желите ли да сачувате ове измене?</translation>
    </message>
</context>
<context>
    <name>qsynthPaletteForm::PaletteModel</name>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1072"/>
        <source>Color Role</source>
        <translation>Улога боје</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1075"/>
        <source>Active</source>
        <translation>Укључено</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1078"/>
        <source>Inactive</source>
        <translation>Искључено</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1081"/>
        <source>Disabled</source>
        <translation>Онемогућено</translation>
    </message>
</context>
<context>
    <name>qsynthPresetForm</name>
    <message>
        <location filename="../qsynthPresetForm.ui" line="33"/>
        <source>Channel Preset</source>
        <translation>Поставка канала</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="65"/>
        <source>Preset</source>
        <translation>Поставка</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="93"/>
        <source>Bank selector</source>
        <translation>Изборник банке</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="118"/>
        <source>Bank</source>
        <translation>Банка</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="124"/>
        <source>Program selector</source>
        <translation>Изборник програма</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="149"/>
        <source>Prog</source>
        <translation>Програм</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="154"/>
        <source>Name</source>
        <translation>Назив</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="159"/>
        <source>SFID</source>
        <translation>З-ИБ</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="164"/>
        <source>Soundfont</source>
        <translation>Звукотека</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="173"/>
        <source>Whether to preview the current selection</source>
        <translation>Омогућава преглед текућег избора</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="176"/>
        <source>Preview</source>
        <translation>Преглед</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.cpp" line="145"/>
        <source>Channel %1</source>
        <translation>Канал %1</translation>
    </message>
</context>
<context>
    <name>qsynthSetupForm</name>
    <message>
        <location filename="../qsynthSetupForm.ui" line="54"/>
        <source>Engine &amp;Name:</source>
        <translation>&amp;Назив покретача:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="67"/>
        <source>Engine display name</source>
        <translation>Приказан назив покретача</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="96"/>
        <source>&amp;MIDI</source>
        <translation>&amp;Миди</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="360"/>
        <source>Whether to show MIDI router events on messages window</source>
        <translation>Омогућава преглед догађаја миди-рутирања у прозорчету са порукама</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="170"/>
        <location filename="../qsynthSetupForm.ui" line="701"/>
        <source>MIDI device name</source>
        <translation>Назив миди-уређаја</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="102"/>
        <source>Enable MIDI input</source>
        <translation>Омогући миди-улаз</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="105"/>
        <source>Enable MIDI &amp;Input</source>
        <translation>Омогућ&amp;и миди-улаз</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="125"/>
        <source>Input MIDI driver</source>
        <translation>Миди посредник на улазу</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="350"/>
        <source>Print out verbose messages about MIDI events</source>
        <translation>Штампај опширније поруке о миди-догађајима</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="353"/>
        <source>&amp;Verbose MIDI event messages</source>
        <translation>Опширни&amp;је поруке о миди-догађају</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="183"/>
        <source>MIDI &amp;Channels:</source>
        <translation>Миди-&amp;канали:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="196"/>
        <source>Number of MIDI channels</source>
        <translation>Број миди-канала</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="225"/>
        <source>MIDI &amp;Bank Select mode:</source>
        <translation>Начин избора миди-&amp;банке:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="238"/>
        <source>MIDI Bank Select mode</source>
        <translation>Начин избора миди-банке</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="245"/>
        <source>gm</source>
        <translation>ЏМ</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="250"/>
        <source>gs</source>
        <translation>ГС</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="255"/>
        <source>mma</source>
        <translation>ММА</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="260"/>
        <source>xs</source>
        <translation>Икс-С</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="305"/>
        <source>ALSA Sequencer client name identification</source>
        <translation>Идентификација назива АЛСА секвенцер клијента</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="312"/>
        <source>pid</source>
        <translation>ПИБ</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="317"/>
        <location filename="../qsynthSetupForm.ui" line="800"/>
        <source>qsynth</source>
        <translation>Ку-синт</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="371"/>
        <source>&amp;Audio</source>
        <translation>&amp;Звук</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="418"/>
        <source>Sample &amp;Format:</source>
        <translation>О&amp;блик узорка:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="408"/>
        <source>Output audio driver</source>
        <translation>Звучни посредник на излазу</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="112"/>
        <source>MIDI &amp;Driver:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="148"/>
        <source>MIDI D&amp;evice:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="292"/>
        <source>MIDI Client &amp;Name ID (ALSA/CoreMidi):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="340"/>
        <source>Attempt to connect the MIDI inputs to the physical ports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="343"/>
        <source>&amp;Auto Connect MIDI Inputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="363"/>
        <source>D&amp;ump MIDI router events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="395"/>
        <source>Audio &amp;Driver:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="431"/>
        <source>Sample format</source>
        <translation>Облик (формат) узорка</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="508"/>
        <source>Period size in bytes (audio buffer size)</source>
        <translation>Величина периода у бајтима (вел. звучног бафера)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="515"/>
        <location filename="../qsynthSetupForm.ui" line="603"/>
        <source>64</source>
        <translation>64</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="520"/>
        <source>128</source>
        <translation>128</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="525"/>
        <source>256</source>
        <translation>256</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="530"/>
        <source>512</source>
        <translation>512</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="535"/>
        <source>1024</source>
        <translation>1024</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="540"/>
        <source>2048</source>
        <translation>2048</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="545"/>
        <source>4096</source>
        <translation>4096</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="550"/>
        <source>8192</source>
        <translation>8192</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="558"/>
        <source>Buffer Cou&amp;nt:</source>
        <translation>Број&amp;ност бафера:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="457"/>
        <source>Sample rate in samples per second (Hz)</source>
        <translation>Учестаност узорковања у узорцима у секунди (Hz)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="467"/>
        <source>22050</source>
        <translation>22050</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="472"/>
        <source>44100</source>
        <translation>44100</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="477"/>
        <source>48000</source>
        <translation>48000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="482"/>
        <source>88200</source>
        <translation>88200</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="487"/>
        <source>96000</source>
        <translation>96000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="444"/>
        <source>Sample &amp;Rate:</source>
        <translation>Учестаност узо&amp;рковања:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="571"/>
        <source>Period count (number of audio buffers)</source>
        <translation>Бројност периода (количина, број звучних бафера)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="578"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="583"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="588"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="593"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="598"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="495"/>
        <source>Buffer &amp;Size:</source>
        <translation>&amp;Величина бафера:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="637"/>
        <source>Audio &amp;Channels:</source>
        <translation>Звучни &amp;канали:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="653"/>
        <source>Number of audio groups</source>
        <translation>Бројност звучних група</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="666"/>
        <source>Number of enabled polyphonic voices</source>
        <translation>Број омогућених вишезвучних (полифоних) гласова</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="682"/>
        <source>Number of stereo audio channels</source>
        <translation>Број звучних стерео канала</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="714"/>
        <source>&amp;Polyphony:</source>
        <translation>Ви&amp;шезвучје:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="746"/>
        <source>Audio &amp;Groups:</source>
        <translation>Звучне &amp;групе:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="785"/>
        <source>JACK client name identification</source>
        <translation>Идентификација назива Џек-клијента</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="795"/>
        <source>fluidsynth</source>
        <translation>Флуид-синт</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="823"/>
        <source>Attempt to connect the JACK outputs to the physical ports</source>
        <translation>Покушавај да повежеш излазе Џек посредника на физичке портове</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="618"/>
        <source>Audio D&amp;evice:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="772"/>
        <source>JACK Client &amp;Name ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="826"/>
        <source>&amp;Auto Connect JACK Outputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="833"/>
        <source>Create multiple JACK output ports for channels, groups and effects</source>
        <translation>Створи вишеструке излазе за канале групе и ефекте у Џек посреднику</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="836"/>
        <source>&amp;Multiple JACK Outputs</source>
        <translation>Виш&amp;еструки излази у Џек посреднику</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="859"/>
        <source>&amp;WASAPI Exclusive Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="867"/>
        <source>&amp;Soundfonts</source>
        <translation>&amp;Звукотеке</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="882"/>
        <source>Soundfont stack</source>
        <translation>Библиотека звукотека</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="904"/>
        <source>SFID</source>
        <translation>З-ИБ</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="909"/>
        <location filename="../qsynthSetupForm.ui" line="1051"/>
        <source>Name</source>
        <translation>Назив</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="914"/>
        <source>Offset</source>
        <translation>Офсет</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="927"/>
        <source>Open soundfont file for loading</source>
        <translation>Отвори звукотеку за учитавање</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="930"/>
        <source>&amp;Open...</source>
        <translation>&amp;Отвори…</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="940"/>
        <source>Edit selected soundfont bank offset</source>
        <translation>Уреди офсет за изабрану банку звукотеке</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="943"/>
        <source>&amp;Edit</source>
        <translation>Ур&amp;еди</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="953"/>
        <source>Remove selected soundfont from stack</source>
        <translation>Уклони изабрану звукотеку из бибиотеке</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="956"/>
        <source>&amp;Remove</source>
        <translation>&amp;Уклони</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="979"/>
        <source>Move up selected soundfont towards the top of stack</source>
        <translation>Премести звукотеку ка врху</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="982"/>
        <source>&amp;Up</source>
        <translation>&amp;Горе</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="992"/>
        <source>Move down selected soundfont towards the bottom of stack</source>
        <translation>Премести звукотеку ка дну</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="995"/>
        <source>&amp;Down</source>
        <translation>&amp;Доле</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1008"/>
        <source>S&amp;ettings</source>
        <translation>Под&amp;ешавања</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1056"/>
        <source>Type</source>
        <translation>Врста</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1061"/>
        <source>Realtime</source>
        <translation>У стварном времену</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1066"/>
        <source>Current</source>
        <translation>Тренутно</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1071"/>
        <source>Default</source>
        <translation>Подразумевано</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1076"/>
        <source>Min</source>
        <translation>Мин.</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1081"/>
        <source>Max</source>
        <translation>Макс.</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1086"/>
        <source>Options</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="34"/>
        <location filename="../qsynthSetupForm.cpp" line="405"/>
        <source>Setup</source>
        <translation>Поставке</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="637"/>
        <location filename="../qsynthSetupForm.cpp" line="921"/>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="638"/>
        <source>Some settings have been changed.</source>
        <translation>Измењена су нека подешавања.</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="639"/>
        <source>Do you want to apply the changes?</source>
        <translation>Желите ли да примените ове измене?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="857"/>
        <source>Open...</source>
        <translation>Отвори…</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="862"/>
        <source>Edit</source>
        <translation>Уреди</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="867"/>
        <source>Remove</source>
        <translation>Уклони</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="872"/>
        <source>Move Up</source>
        <translation>Подигни</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="876"/>
        <source>Move Down</source>
        <translation>Спусти</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="901"/>
        <location filename="../qsynthSetupForm.cpp" line="902"/>
        <source>Soundfont files</source>
        <translation>Звукотеке</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="903"/>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="922"/>
        <source>Soundfont file already on list</source>
        <translation>Звукотека је већ на списку</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="924"/>
        <source>Add anyway?</source>
        <translation>Да ли да је додам упркос томе?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="951"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="952"/>
        <source>Failed to add soundfont file</source>
        <translation>Нисам успео да додам звукотеку</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="954"/>
        <source>Please, check for a valid soundfont file.</source>
        <translation>Потражите ваљану звукотеку.</translation>
    </message>
</context>
</TS>
